Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
.tox/p313/lib/python3.13/site-packages/scicom/__init__.py | 0 | 0 | 0 | 100%
.tox/p313/lib/python3.13/site-packages/scicom/historicalletters/__init__.py | 0 | 0 | 0 | 100%
.tox/p313/lib/python3.13/site-packages/scicom/historicalletters/agents.py | 114 | 9 | 0 | 92%
.tox/p313/lib/python3.13/site-packages/scicom/historicalletters/interface.py | 28 | 0 | 0 | 100%
.tox/p313/lib/python3.13/site-packages/scicom/historicalletters/model.py | 111 | 3 | 0 | 97%
.tox/p313/lib/python3.13/site-packages/scicom/historicalletters/space.py | 27 | 0 | 0 | 100%
.tox/p313/lib/python3.13/site-packages/scicom/historicalletters/utils.py | 38 | 0 | 0 | 100%
.tox/p313/lib/python3.13/site-packages/scicom/interface.py | 14 | 14 | 0 | 0%
.tox/p313/lib/python3.13/site-packages/scicom/knowledgespread/SimpleContinuousModule.py | 23 | 23 | 0 | 0%
.tox/p313/lib/python3.13/site-packages/scicom/knowledgespread/__init__.py | 0 | 0 | 0 | 100%
.tox/p313/lib/python3.13/site-packages/scicom/knowledgespread/agents.py | 71 | 71 | 0 | 0%
.tox/p313/lib/python3.13/site-packages/scicom/knowledgespread/interface.py | 5 | 5 | 0 | 0%
.tox/p313/lib/python3.13/site-packages/scicom/knowledgespread/model.py | 71 | 71 | 0 | 0%
.tox/p313/lib/python3.13/site-packages/scicom/knowledgespread/server.py | 65 | 65 | 0 | 0%
.tox/p313/lib/python3.13/site-packages/scicom/knowledgespread/utils.py | 127 | 127 | 0 | 0%
.tox/p313/lib/python3.13/site-packages/scicom/run.py | 7 | 7 | 0 | 0%
.tox/p313/lib/python3.13/site-packages/scicom/utilities/__init__.py | 0 | 0 | 0 | 100%
.tox/p313/lib/python3.13/site-packages/scicom/utilities/statistics.py | 109 | 9 | 0 | 92%
Total | 810 | 404 | 0 | 50%

No items found using the specified filter.